@@ -9,7 +9,7 @@ test_that("rm_abbreviation is removing 'all abbreviation' strings",{
     x2 <- c("I want $2.33 at 2:30 to go to", "She will send it ( as soon as you can) said I.", 
         "Hello world.", "In the")
 
-    expect_true(identical(rm_abbreviation(x), x2))
+    expect_equivalent(rm_abbreviation(x), x2)
 	
 })
 
@@ -23,8 +23,7 @@ test_that("rm_abbreviation is extracting 'all abbreviation' strings",{
     x3 <- list(c("p.m.", "A.n.p."), c("A.S.A.P.", "e.g."), NA_character_, 
         "U. S. A.")
 
-    expect_true(identical(rm_abbreviation(x, extract=TRUE), x3))
+    expect_equivalent(rm_abbreviation(x, extract=TRUE), x3)
 })
 
 
-
